# Canonical Store Api - Python package

## How to install

To install this extension as a requirement in your project, you can use PIP:

```bash
pip install canonicalwebteam.store-api
```

See also the documentation for [pip install](https://pip.pypa.io/en/stable/reference/pip_install/).

## Development

The package leverages [poetry](https://poetry.eustace.io/) for dependency management.

## Testing

All tests can be run with `poetry run pytest`.
